program test_x2f_mpi
!
! A test program calling x2f_mpi library to make sure it works.
! It has function of swapping the first two columns of a rank-2 array.
! 
use MPI

implicit none
integer  :: nx, nf, nv, ldxf, k_pos, mode, nSR2, info_imp(10), info_xf(1)
real(kind(1.d0))  :: rinfo_xf(1)
real(kind(1.d0)), allocatable  :: x(:,:), f(:,:), xf(:,:), errxf(:)

integer  :: ierr, rank_in_world, ipar, itest
real     :: temp

call MPI_INIT( ierr )
call MPI_COMM_RANK( MPI_COMM_WORLD, rank_in_world, ierr )

nx = 2
nf = 3
ldxf = max(nx,nf)
nv = 10
nv = nv * ( rank_in_world+1 )

allocate(  x(ldxf,nv)  )
allocate(  f(ldxf,nv)  )
allocate(  xf(ldxf,nv) )
allocate(  errxf(nf)   )

do ipar = 1, nv
   x(1,ipar)  = ipar
   call random_number( temp )
   x(2,ipar)  = temp
end do

! Store the correct results in f array
info_xf  = 2
rinfo_xf = 0.0
k_pos    = 1
do ipar = 1, nv
   call x2f_cirxn( nf, nx, x(1:nx,ipar), f(1:nf,ipar), k_pos, info_xf, rinfo_xf )
end do

do itest = 1, 20   
   xf = x
   mode     = 1
   info_imp = 0
   nSR2 = 0 
   ! Store the results produced by using x2f_mpi library in xf array
   call ISAT_MP( nx, nf, ldxf, nv, xf, mode, nSR2, info_imp, itest )

   ! Compare two results(f and xf) to check the correctness
   errxf(1:nf) = sum(dabs(xf(1:nf,1:nv)-f(1:nf,1:nv)),dim=2)
   if ( maxval(errxf(1:nf))>0.0 ) then
      print *, 'Test Failed!'
      print *, 'mode =', mode
      stop
   else
      print *, 'succeed in mode=', mode, itest
   end if
end do

deallocate(   x   )
deallocate(   f   )
deallocate(  xf   )
deallocate( errxf )

end program test_x2f_mpi
